<?PHP
/*
Plugin Name: Auto Post Images (API)
Plugin URI: http://karthikeyan.karunanidhi.com/
Version: v1.1.1
Author: <a href="http://karthikeyan.karunanidhi.com/">Karthikeyan Karunanidhi</a>
Description: This plugin will automatically put images into each blog post. All you have to do is upload the image into the '/wp-content/plugins/auto-post-images/images/' directory and name them as 'Image_POSTID[_SUFFIX].jpg' where 'POSTID' is ID of blog post and if you have more than one image then you can add any prefix after the 'POSTID' separated by an underscore. Blog Posts that do not have image will show a default image. Example Image Name: Image_66.jpg, Image_66_a.jpg, Image_66_two.gif, etc.

Copyright Karthikeyan Karunanidhi (email : wordpress [a t ] karunanidhi DOT com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

	if (!class_exists("KKAutoPostImages")) {

		require_once (dirname(__FILE__) . '/php/Filesystem.class.php');

		/**
		* Auto Post Images (API) class
		*
		* Methods and variables for the Auto Post Images (API) plugin. Inserts images automatically into blog posts based on their POSTID
		*
		* @author Karthikeyan Karunanidhi <wordpress@karunanidhi.com>
		* @access public
		* @copyright GNU General Public License.
		* @package com.karunanidhi.karthikeyan
		*/
		class KKAutoPostImages {

			/**
			* The ID of the blog post. Set to $post->ID using global $post
			*/
			var $iPostId = 0;

			/**
			* The directory path to the images folder. Make sure you put the plugin files in /wp-content/plugins/auto-post-images/
			*/
			var $sImageDirPath = '';

			/**
			* The URL to the images folder. Make sure you put the plugin files in /wp-content/plugins/auto-post-images/
			*/
			var $sImageDirUrl = '';

			/**
			* The URL of the default image that is displayed on a blog post when images are not found for that blog post
			*/
			var $sDefaultImageUrl = '';

			/**
			* Unique name to use for the plugin settings screen
			*/
			var $sAdminOptionsName = 'KK_API_ADMIN_OPTIONS';

			/**
			* Plugin settings
			*/
			var $aAdminOptions = array (
											"bDisplayDefaultImage" => 'YES'
										);

			/**
			* Constructor. Calls the init method
			*/
			function KKAutoPostImages () {

				$this->init();
			}

			/**
			* Calls the getAdminOptions method
			*/
			function init () {

				$this->getAdminOptions();
			}

			/**
			* Gets the plugin settings from the database and initializes the plugin settings
			*
			* @return array The plugins setting
			*/
			function getAdminOptions () {

				$mAdminOptions = get_option($this->sAdminOptionsName);

				if( !empty($mAdminOptions) ) {

					foreach( $mAdminOptions as $sKey => $mOption ) {

						$this->aAdminOptions[$sKey] = $mOption;
					}
				}

				update_option($this->sAdminOptionsName, $this->aAdminOptions);

				return $this->aAdminOptions;
			}

			/**
			* The meat of the plugin. Searches for images for a blog post and inserts the image into the blog posts content
			*
			* @param string $sContent The content of the blog post
			* @return string The content of the blog post with the image code
			*/
			function showImagesByPostId ($sContent) {

				if(is_page()) {

					return $sContent;
				}

				global $post;
				$this->iPostId = $post->ID;
				$sHtml = '';

				if( $this->iPostId == FALSE || !is_numeric($this->iPostId) ) {

					$this->iPostId = 0;
				}

				$this->sImageDirPath = dirname(__FILE__) . '/images/';
				$this->sImageDirUrl = get_bloginfo('wpurl') . '/wp-content/plugins/auto-post-images/images/';
				$this->sDefaultImageUrl = $this->sImageDirUrl . 'imagecomingsoon.jpg';

				$aImageFiles = $this->getImagesForThisPost($this->iPostId);

				foreach($aImageFiles as $key => $sImagePath) {

					$sImageDirPath = $this->sImageDirPath . $sImagePath;

					if( !is_file($sImageDirPath) ) {

						unset($aImageFiles[$key]);
					}

					$aImageFiles[$key] = $this->sImageDirUrl . $sImagePath;
				}

				if( empty($aImageFiles) && $this->aAdminOptions['bDisplayDefaultImage'] == 'YES') {

					$aImageFiles[] = $this->sDefaultImageUrl;
				}

				$sHtml .= '<div class="kkautopostimage">';

				foreach($aImageFiles as $key => $sImagePath) {

					$sHtml .= "<img src=\"{$sImagePath}\" alt=\"Image\" title=\"Image\" /><br />";
				}

				$sHtml .= '</div>';

				return $sHtml . $sContent;
			}

			/**
			* Hooked into 'wp_head' and inserts the css <link> tag into the pages <head>
			*/
			function includeCSS () {

				echo '<link type="text/css" rel="stylesheet" href="' . get_bloginfo('wpurl') . '/wp-content/plugins/auto-post-images/css/kkimageinpost.css" />' . "\n";
			}

			/**
			* Searches the /wp-content/plugins/auto-post-images/images/ folder for images for the given blog post ID and returns the filename
			*
			* @param int $iPostId The ID of the blog POST
			* @return array List of image file names
			*/
			function getImagesForThisPost($iPostId) {

				$oFileSys = new Filesystem();
				$sPattern = "^Image_{$iPostId}[_]?[0-9a-zA-Z]*\.[a-zA-Z]+$";
				$aImages = $oFileSys->readDir($this->sImageDirPath, $sPattern);

				return $aImages;
			}

			/**
			* Hooked into 'admin_menu' sets-up the plugins setting page handles the settings update
			*/
			function printAdminPage () {

				$aAdminOptions = $this->getAdminOptions();

				if (isset($_POST['updateAutoPostImagesSettings'])) {

					if (isset($_POST['AutoPostImagesDisplayDefaultImages'])) {

						$aAdminOptions['bDisplayDefaultImage'] = ( $_POST['AutoPostImagesDisplayDefaultImages'] == 'YES' ) ? 'YES' : 'NO';
					}

					update_option($this->sAdminOptionsName, $aAdminOptions);

					echo '<div class="updated"><p><strong>' . __("Settings Updated.", "KKAutoPostImages") . '</strong></p></div>';
				}

				$sRequestUri = $_SERVER["REQUEST_URI"];

				$sDisplayDefaultImageYesRadio = __(' checked="checked" ', 'KKAutoPostImages');
				$sDisplayDefaultImageNoRadio = '';
				$sUpdateAutoPostImagesSubmitButton = __('Update Settings', 'KKAutoPostImages');

				if ( $aAdminOptions['bDisplayDefaultImage'] == 'YES' ) {

					$sDisplayDefaultImageYesRadio = __(' checked="checked" ', 'KKAutoPostImages');
					$sDisplayDefaultImageNoRadio = '';

				} else {

					$sDisplayDefaultImageYesRadio = '';
					$sDisplayDefaultImageNoRadio = __(' checked="checked" ', 'KKAutoPostImages');
				}

				echo "
						<div class=\"wrap\">

							<form method=\"post\" action=\"{$sRequestUri}\">

								<h2>Auto Post Images (API) Settings</h2>

								<h3>Display default image if not image is found?</h3>

								<p>
									<input type=\"radio\" id=\"AutoPostImagesDisplayDefaultImages_yes\" name=\"AutoPostImagesDisplayDefaultImages\" value=\"YES\" {$sDisplayDefaultImageYesRadio} /> <label for=\"AutoPostImagesDisplayDefaultImages_yes\">Yes</label>
									<input type=\"radio\" id=\"AutoPostImagesDisplayDefaultImages_no\" name=\"AutoPostImagesDisplayDefaultImages\" value=\"NO\" {$sDisplayDefaultImageNoRadio} /> <label for=\"AutoPostImagesDisplayDefaultImages_no\">No</label>
								</p>

								<p>Selecting &quot;No&quot; will hide the default &quot;Image coming soon&quot; image if no images are found for the post.</p>


								<div class=\"submit\">
									<input type=\"submit\" name=\"updateAutoPostImagesSettings\" value=\"{$sUpdateAutoPostImagesSubmitButton}\" />
								</div>
							</form>
						</div>
				";
			}

		} // End Class KKAutoPostImages

	} // End if


	//
	// Initialize the admin panel
	//
	if (!function_exists("AutoPostImages_AdminPageFunc")) {

		function AutoPostImages_AdminPageFunc () {

			global $oKKAutoPostImages;

			if ( !isset($oKKAutoPostImages) ) {

				return;
			}

			if ( function_exists('add_options_page') ) {

				add_options_page('Auto Post Images (API) Settings', 'Auto Post Images (API) Settings', 9, basename(__FILE__), array(&$oKKAutoPostImages, 'printAdminPage'));
			}
		}
	}

	/*
	 *
	 *    Initializing the class and hooking into wordpress
	 *
	 */

	if (class_exists("KKAutoPostImages")) {

		$oKKAutoPostImages = new KKAutoPostImages();
	}

	// Actions and Filters
	//
	if (isset($oKKAutoPostImages)) {

		//
		// Actions
		//

		// Admin screen for the Auto Post Images (API) plugin
		//
		add_action('admin_menu', 'AutoPostImages_AdminPageFunc');

		// Add the css file to the page <head>
		//
		add_action('wp_head', array(&$oKKAutoPostImages, 'includeCSS'), 1);

		// Call the init function to initialize the admin options
		//
		add_action('activate_auto-post-images/auto-post-images.php',  array(&$oKKAutoPostImages, 'init'));

		//
		// Filters
		//

		// Add the image to the post content
		//
		add_filter('the_content', array(&$oKKAutoPostImages, 'showImagesByPostId'));
	}

?>